<?php

declare(strict_types=1);

namespace Drupal\views_remote_data\Plugin\views\argument;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\argument\ArgumentPluginBase;
use Drupal\views_remote_data\Plugin\views\query\RemoteDataQuery;

/**
 * Views argument for remote data.
 *
 * @ViewsArgument("views_remote_data_property")
 */
final class PropertyArgument extends ArgumentPluginBase {

  /**
   * {@inheritdoc}
   */
  protected function defineOptions(): array {
    $options = parent::defineOptions();
    $options['property_path'] = ['default' => ''];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state): void {
    $form['property_path'] = [
      '#title' => $this->t('Property path from incoming object'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => $this->options['property_path'] ?? '',
    ];
    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function query($group_by = FALSE): void {
    assert($this->query instanceof RemoteDataQuery);
    $property = explode('.', $this->options['property_path']);
    $this->query->addWhere(0, $property, $this->argument);
  }

}
