<?php

declare(strict_types=1);

namespace Drupal\views_remote_data\Plugin\views\field;

use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * Field plugin to extract a value from the result at a property path.
 *
 * @ViewsField("views_remote_data_property")
 */
final class PropertyField extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function query(): void {
    // Do nothing here.
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(ResultRow $values, $field = NULL) {
    $property_path = explode('.', $this->options['property_path']);
    $property_name = array_shift($property_path);

    if (!isset($values->{$property_name})) {
      return NULL;
    }
    $value = $values->{$property_name};
    // Direct field, no properties.
    if (count($property_path) === 0) {
      return $value;
    }
    // Convert a generic object into an array.
    if ($value instanceof \stdClass) {
      $value = (array) $value;
    }
    // This isn't an array value, bail out. Bad property path.
    if (!is_array($value)) {
      return NULL;
    }
    return NestedArray::getValue($value, $property_path);
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions(): array {
    $options = parent::defineOptions();
    $options['property_path'] = ['default' => ''];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state): void {
    $form['property_path'] = [
      '#title' => $this->t('Property path from incoming object'),
      '#type' => 'textfield',
      '#default_value' => $this->options['property_path'] ?? '',
    ];
    parent::buildOptionsForm($form, $form_state);
  }

}
