<?php

declare(strict_types=1);

namespace Drupal\views_remote_data_test\EventSubscriber;

use Drupal\Component\Serialization\Json;
use Drupal\Component\Utility\NestedArray;
use Drupal\views\ResultRow;
use Drupal\views_remote_data\Events\RemoteDataLoadEntitiesEvent;
use Drupal\views_remote_data\Events\RemoteDataQueryEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Test subscriber for populating values in test views.
 */
final class ViewsRemoteDataSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      RemoteDataQueryEvent::class => 'onQuery',
      RemoteDataLoadEntitiesEvent::class => 'onLoadEntities',
    ];
  }

  /**
   * Subscribes to populate entities against the results.
   *
   * @param \Drupal\views_remote_data\Events\RemoteDataLoadEntitiesEvent $event
   *   The event.
   *
   * @todo need tests which test this.
   */
  public function onLoadEntities(RemoteDataLoadEntitiesEvent $event): void {

  }

  /**
   * Subscribes to populate the view results.
   *
   * @param \Drupal\views_remote_data\Events\RemoteDataQueryEvent $event
   *   The event.
   */
  public function onQuery(RemoteDataQueryEvent $event): void {
    $base_tables = array_keys($event->getView()->getBaseTables());
    if (in_array('views_remote_data_test_simple', $base_tables, TRUE)) {
      $fixture = Json::decode((string) file_get_contents(__DIR__ . '/../../../../fixtures/simple.json'));
      $conditions = $event->getConditions();
      foreach ($fixture['data'] as $item) {
        foreach ($conditions as $condition) {
          $value = NestedArray::getValue($item, $condition['field']);
          if ($condition['operator'] === '=') {
            if ($value !== $condition['value']) {
              continue 2;
            }
          }
          else {
            continue 2;
          }
        }
        $event->addResult(new ResultRow($item));

      }
    }
  }

}
