<?php

declare(strict_types=1);

namespace Drupal\Tests\views_remote_data\Kernel;

use Drupal\views\ViewExecutable;
use Drupal\views\Views;

/**
 * Views integration testing.
 *
 * @group views_remote_data
 */
final class ViewsIntegrationTest extends ViewsRemoteDataTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'views_remote_data_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig(['views_remote_data_test']);
  }

  /**
   * Tests that base tables can be used as check in subscriber.
   */
  public function testSimple(): void {
    $view = Views::getView('views_remote_data_test');
    $this->executeView($view);
    self::assertCount(2, $view->result);
    $view = Views::getView('views_remote_data_other_test');
    $this->executeView($view);
    self::assertCount(2, $view->result);
    // This view's base table is ignored.
    $view = Views::getView('views_remote_data_none_test');
    $this->executeView($view);
    self::assertCount(0, $view->result);

    $this->assertCount(6, $this->caughtEvents);
  }

  /**
   * Tests using args.
   */
  public function testArgs(): void {
    $view = Views::getView('views_remote_data_test');
    $this->executeView($view, 'default', [
      'name' => 'Alpaca',
    ]);
    self::assertCount(1, $view->result);
  }

  /**
   * Executes a view.
   *
   * @param \Drupal\views\ViewExecutable $view
   *   The view.
   * @param string $display_id
   *   The display ID.
   * @param array $args
   *   The args.
   */
  private function executeView(ViewExecutable $view, string $display_id = 'default', array $args = []): void {
    $view->setDisplay($display_id);
    $view->executeDisplay($display_id, $args);
    $view->execute();
  }

}
